#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
#
# Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
# $Revision: 11172 $

import random

from django.contrib import admin

from Iuno.cloud.sms.models import Token
from Iuno.cloud.sms.forms import TokenAdminForm

class TokenAdmin(admin.ModelAdmin):
    form = TokenAdminForm
    list_display = ('name', 'username', 'token', 'description')
    
    def get_changeform_initial_data(self, request):
        initialCode = "".join([random.choice('ABCDEFGHIJKLMNOPQRSTUVWXYZ') for i in range(10)])
        return {
            'token': initialCode,
        }
    
admin.site.register(Token, TokenAdmin)